angular.module('ngApp.services', [])
/**
 * services for storage object as json in window.localstorage
 * @type  {factory service}
 */
.factory('localStorage', function() {
  return {
	all: function(key) {
	  var data = window.localStorage[key];
	  if(data) {
		return angular.fromJson(data);
	  }
	  return {};
	},
	save: function(data,key) {
	  window.localStorage[key] = angular.toJson(data);
	},
	clear: function(key) {
	  window.localStorage.removeItem(key);
	},
	get: function(key,id) {
	  var data = window.localStorage[key];
	  if(data) {
		data = angular.fromJson(data);
		return data[id];
	  }
	  return {};
    },
	add: function(data,key) {
		var old_data = window.localStorage[key];
		if(old_data) {
			old_data = angular.fromJson(old_data);
			data = angular.merge(old_data, data);
		}
		window.localStorage[key] = angular.toJson(data);
	}
  }
})
/**
 * conver string to standard date format for ng-model in input type date
 * @type  {directive}
 * @return  {intiger} standard date format
 */
.directive('stringToDate', function() {
    return {
        restrict : 'A',
        require: 'ngModel',
        link: function(scope, element, attrs, ngModel) {
            ngModel.$parsers.push(function(value) {
                return '' + value;
            });
            ngModel.$formatters.push(function(date) {
                return new Date(date);
            });
        }
    }
})
/**
 * String to number for ng-model in number input
 * @type  {directive}
 * @return  {intiger} standard number format
 */
.directive('stringToNumber', function() {
    return {
        restrict : 'A',
        require: 'ngModel',
        link: function(scope, element, attrs, ngModel) {
            ngModel.$parsers.push(function(value) {
                return '' + value;
            });
            ngModel.$formatters.push(function(value) {
                return parseFloat(value);
            });
        }
    };
})
/**
 * String to time for ng-model in time input
 * @type  {directive}
 * @return  {time} standard time format
 */
.directive('stringToTime', function() {
    return {
        restrict : 'A',
        require: 'ngModel',
        link: function(scope, element, attrs, ngModel) {
            ngModel.$parsers.push(function(value) {
                return '' + value;
            });
            ngModel.$formatters.push(function(value) {
                return parseFloat(value);
            });
        }
    };
})
/**
 * String to time for ng-model in time input
 * @type  {directive}
 * @return  {time} standard time format
 */
.directive('stringToBoolean', function() {
    return {
        restrict : 'A',
        require: 'ngModel',
        link: function(scope, element, attrs, ngModel) {
            ngModel.$parsers.push(function(value) {
                return '' + value;
            });
            ngModel.$formatters.push(function(value) {
                return value == '1' ||  value == 'true';
            });
        }
    };
})
.directive('backButton', function () {
    return {
        restrict: 'E',
        replace: true,
        controller: function($scope, $ionicHistory){
            $scope.canGoBack = false;
            if ($ionicHistory.backView()) {
                $scope.canGoBack = true;
            }
            $scope.goBack = function() {
                $ionicHistory.goBack();
            }
        },
        template: [
            '<button class="button back-buttonx buttons button-clear" ng-show="canGoBack" ng-click="goBack()">',
            '<i class="icon ion-arrow-left-c"></i>',
            '</button>',
        ].join('')
    };
});
